@@ -1,5 +1,5 @@
 #
-# Copyright 2013-2020 Ghent University
+# Copyright 2013-2021 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -46,7 +46,6 @@ _log = fancylogger.getLogger('easyconfig.templates', fname=False)
 
 # derived from easyconfig, but not from ._config directly
 TEMPLATE_NAMES_EASYCONFIG = [
-    ('arch', "System architecture (e.g. x86_64, aarch64, ppc64le, ...)"),
     ('module_name', "Module name"),
     ('nameletter', "First letter of software name"),
     ('toolchain_name', "Toolchain name"),
@@ -80,11 +79,24 @@ TEMPLATE_NAMES_EASYBLOCK_RUN_STEP = [
 TEMPLATE_SOFTWARE_VERSIONS = [
     # software name, prefix for *ver and *shortver
     ('CUDA', 'cuda'),
+    ('CUDAcore', 'cuda'),
     ('Java', 'java'),
     ('Perl', 'perl'),
     ('Python', 'py'),
     ('R', 'r'),
 ]
+# template values which are only generated dynamically
+TEMPLATE_NAMES_DYNAMIC = [
+    ('arch', "System architecture (e.g. x86_64, aarch64, ppc64le, ...)"),
+    ('mpi_cmd_prefix', "Prefix command for running MPI programs (with default number of ranks)"),
+    ('cuda_compute_capabilities', "Comma-separated list of CUDA compute capabilities, as specified via "
+     "--cuda-compute-capabilities configuration option or via cuda_compute_capabilities easyconfig parameter"),
+    ('cuda_cc_space_sep', "Space-separated list of CUDA compute capabilities"),
+    ('cuda_cc_semicolon_sep', "Semicolon-separated list of CUDA compute capabilities"),
+    ('cuda_sm_comma_sep', "Comma-separated list of sm_* values that correspond with CUDA compute capabilities"),
+    ('cuda_sm_space_sep', "Space-separated list of sm_* values that correspond with CUDA compute capabilities"),
+]
+
 # constant templates that can be used in easyconfigs
 TEMPLATE_CONSTANTS = [
     # source url constants
@@ -143,6 +155,19 @@ for ext in extensions:
         ('SOURCE_%s' % suffix, '%(name)s-%(version)s.' + ext, "Source .%s bundle" % ext),
         ('SOURCELOWER_%s' % suffix, '%(namelower)s-%(version)s.' + ext, "Source .%s bundle with lowercase name" % ext),
     ]
+for pyver in ('py2.py3', 'py2', 'py3'):
+    if pyver == 'py2.py3':
+        desc = 'Python 2 & Python 3'
+        name_infix = ''
+    else:
+        desc = 'Python ' + pyver[-1]
+        name_infix = pyver.upper() + '_'
+    TEMPLATE_CONSTANTS += [
+        ('SOURCE_%sWHL' % name_infix, '%%(name)s-%%(version)s-%s-none-any.whl' % pyver,
+         'Generic (non-compiled) %s wheel package' % desc),
+        ('SOURCELOWER_%sWHL' % name_infix, '%%(namelower)s-%%(version)s-%s-none-any.whl' % pyver,
+         'Generic (non-compiled) %s wheel package with lowercase name' % desc),
+    ]
 
 # TODO derived config templates
 # versionmajor, versionminor, versionmajorminor (eg '.'.join(version.split('.')[:2])) )
@@ -232,15 +257,20 @@ def template_constant_dict(config, ignore=None, skip_lower=None, toolchain=None)
         #  a cyclic import...);
         # we need to know to determine whether we're iterating over a list of build dependencies
         is_easyconfig = hasattr(config, 'iterating') and hasattr(config, 'iterate_options')
-
         if is_easyconfig:
             # if we're iterating over different lists of build dependencies,
             # only consider build dependencies when we're actually in iterative mode!
             if 'builddependencies' in config.iterate_options:
                 if config.iterating:
-                    deps += config.get('builddependencies', [])
+                    deps.extend(config.get('builddependencies', []))
             else:
-                deps += config.get('builddependencies', [])
+                deps.extend(config.get('builddependencies', []))
+
+            # include all toolchain deps (e.g. CUDAcore component in fosscuda);
+            # access Toolchain instance via _toolchain to avoid triggering initialization of the toolchain!
+            if config._toolchain is not None:
+                if config._toolchain.tcdeps is not None:
+                    deps.extend(config._toolchain.tcdeps)
 
         for dep in deps:
             if isinstance(dep, dict):
@@ -294,6 +324,10 @@ def template_constant_dict(config, ignore=None, skip_lower=None, toolchain=None)
         except Exception:
             _log.warning("Failed to get .lower() for name %s value %s (type %s)", name, value, type(value))
 
+    # keep track of names of defined templates until now,
+    # so we can check whether names of additional dynamic template values are all known
+    common_template_names = set(template_values.keys())
+
     # step 5. add additional conditional templates
     if toolchain is not None and hasattr(toolchain, 'mpi_cmd_prefix'):
         try:
@@ -310,10 +344,20 @@ def template_constant_dict(config, ignore=None, skip_lower=None, toolchain=None)
     cuda_compute_capabilities = build_option('cuda_compute_capabilities') or config.get('cuda_compute_capabilities')
     if cuda_compute_capabilities:
         template_values['cuda_compute_capabilities'] = ','.join(cuda_compute_capabilities)
+        template_values['cuda_cc_space_sep'] = ' '.join(cuda_compute_capabilities)
+        template_values['cuda_cc_semicolon_sep'] = ';'.join(cuda_compute_capabilities)
         sm_values = ['sm_' + cc.replace('.', '') for cc in cuda_compute_capabilities]
         template_values['cuda_sm_comma_sep'] = ','.join(sm_values)
         template_values['cuda_sm_space_sep'] = ' '.join(sm_values)
 
+    unknown_names = []
+    for key in template_values:
+        dynamic_template_names = set(x for (x, _) in TEMPLATE_NAMES_DYNAMIC)
+        if not (key in common_template_names or key in dynamic_template_names):
+            unknown_names.append(key)
+    if unknown_names:
+        raise EasyBuildError("One or more template values found with unknown name: %s", ','.join(unknown_names))
+
     return template_values
 
 
