@@ -1,5 +1,5 @@
 # #
-# Copyright 2009-2020 Ghent University
+# Copyright 2009-2021 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -394,7 +394,7 @@ class ModuleGenerator(object):
         """
         raise NotImplementedError
 
-    def getenv_cmd(self, envvar):
+    def getenv_cmd(self, envvar, default=None):
         """
         Return module-syntax specific code to get value of specific environment variable.
         """
@@ -559,6 +559,9 @@ class ModuleGenerator(object):
         # Examples (optional)
         lines.extend(self._generate_section('Examples', self.app.cfg['examples'], strip=True))
 
+        # Citing (optional)
+        lines.extend(self._generate_section('Citing', self.app.cfg['citing'], strip=True))
+
         # Additional information: homepage + (if available) doc paths/urls, upstream/site contact
         lines.extend(self._generate_section("More information", " - Homepage: %s" % self.app.cfg['homepage']))
 
@@ -776,11 +779,19 @@ class ModuleGeneratorTcl(ModuleGenerator):
 
         return txt
 
-    def getenv_cmd(self, envvar):
+    def getenv_cmd(self, envvar, default=None):
         """
         Return module-syntax specific code to get value of specific environment variable.
         """
-        return '$::env(%s)' % envvar
+        if default is None:
+            cmd = '$::env(%s)' % envvar
+        else:
+            values = {
+                'default': default,
+                'envvar': '::env(%s)' % envvar,
+            }
+            cmd = '[if { [info exists %(envvar)s] } { concat $%(envvar)s } else { concat "%(default)s" } ]' % values
+        return cmd
 
     def load_module(self, mod_name, recursive_unload=False, depends_on=False, unload_modules=None, multi_dep_mods=None):
         """
@@ -1196,11 +1207,15 @@ class ModuleGeneratorLua(ModuleGenerator):
 
         return txt
 
-    def getenv_cmd(self, envvar):
+    def getenv_cmd(self, envvar, default=None):
         """
         Return module-syntax specific code to get value of specific environment variable.
         """
-        return 'os.getenv("%s")' % envvar
+        if default is None:
+            cmd = 'os.getenv("%s")' % envvar
+        else:
+            cmd = 'os.getenv("%s") or "%s"' % (envvar, default)
+        return cmd
 
     def load_module(self, mod_name, recursive_unload=False, depends_on=False, unload_modules=None, multi_dep_mods=None):
         """
