@@ -1,5 +1,5 @@
 ##
-# Copyright 2011-2020 Ghent University
+# Copyright 2011-2021 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -73,6 +73,8 @@ AARCH64 = 'AArch64'
 POWER = 'POWER'
 X86_64 = 'x86_64'
 
+ARCH_KEY_PREFIX = 'arch='
+
 # Vendor constants
 AMD = 'AMD'
 APM = 'Applied Micro'
@@ -921,20 +923,29 @@ def pick_dep_version(dep_version):
         result = None
 
     elif isinstance(dep_version, dict):
-        # figure out matches based on dict keys (after splitting on '=')
-        my_arch_key = 'arch=%s' % get_cpu_architecture()
-        arch_keys = [x for x in dep_version.keys() if x.startswith('arch=')]
+        arch_keys = [x for x in dep_version.keys() if x.startswith(ARCH_KEY_PREFIX)]
         other_keys = [x for x in dep_version.keys() if x not in arch_keys]
         if other_keys:
-            raise EasyBuildError("Unexpected keys in version: %s. Only 'arch=' keys are supported", other_keys)
+            other_keys = ','.join(sorted(other_keys))
+            raise EasyBuildError("Unexpected keys in version: %s (only 'arch=' keys are supported)", other_keys)
         if arch_keys:
-            if my_arch_key in dep_version:
-                result = dep_version[my_arch_key]
-                _log.info("Version selected from %s using key %s: %s", dep_version, my_arch_key, result)
+            host_arch_key = ARCH_KEY_PREFIX + get_cpu_architecture()
+            star_arch_key = ARCH_KEY_PREFIX + '*'
+            # check for specific 'arch=' key first
+            if host_arch_key in dep_version:
+                result = dep_version[host_arch_key]
+                _log.info("Version selected from %s using key %s: %s", dep_version, host_arch_key, result)
+            # fall back to 'arch=*'
+            elif star_arch_key in dep_version:
+                result = dep_version[star_arch_key]
+                _log.info("Version selected for %s using fallback key %s: %s", dep_version, star_arch_key, result)
             else:
-                raise EasyBuildError("No matches for version in %s (looking for %s)", dep_version, my_arch_key)
+                raise EasyBuildError("No matches for version in %s (looking for %s)", dep_version, host_arch_key)
+        else:
+            raise EasyBuildError("Found empty dict as version!")
 
     else:
-        raise EasyBuildError("Unknown value type for version: %s", dep_version)
+        typ = type(dep_version)
+        raise EasyBuildError("Unknown value type for version: %s (%s), should be string value", typ, dep_version)
 
     return result
