@@ -1,5 +1,5 @@
 # #
-# Copyright 2013-2020 Ghent University
+# Copyright 2013-2021 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -244,6 +244,9 @@ class EasyBuildConfigTest(EnhancedTestCase):
         cfgtxt = '\n'.join([
             '[config]',
             'installpath = %s' % testpath2,
+            # special case: configuration option to a value starting with '--'
+            '[override]',
+            'optarch = --test',
         ])
         write_file(config_file, cfgtxt)
 
@@ -261,6 +264,8 @@ class EasyBuildConfigTest(EnhancedTestCase):
         self.assertEqual(install_path(), installpath_software)  # via cmdline arg
         self.assertEqual(install_path('mod'), os.path.join(testpath2, 'modules'))  # via config file
 
+        self.assertEqual(options.optarch, '--test')  # via config file
+
         # copy test easyconfigs to easybuild/easyconfigs subdirectory of temp directory
         # to check whether easyconfigs install path is auto-included in robot path
         tmpdir = tempfile.mkdtemp(prefix='easybuild-easyconfigs-pkg-install-path')
