@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # #
-# Copyright 2012-2020 Ghent University
+# Copyright 2012-2021 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -77,6 +77,7 @@ import test.framework.toolchainvariables as tcv
 import test.framework.toy_build as t
 import test.framework.type_checking as et
 import test.framework.tweak as tw
+import test.framework.utilities_test as u
 import test.framework.variables as v
 import test.framework.yeb as y
 
@@ -118,7 +119,7 @@ log = fancylogger.getLogger()
 # call suite() for each module and then run them all
 # note: make sure the options unit tests run first, to avoid running some of them with a readily initialized config
 tests = [gen, bl, o, r, ef, ev, ebco, ep, e, mg, m, mt, f, run, a, robot, b, v, g, tcv, tc, t, c, s, lic, f_c,
-         tw, p, i, pkg, d, env, et, y, st, h, ct, lib]
+         tw, p, i, pkg, d, env, et, y, st, h, ct, lib, u]
 
 SUITE = unittest.TestSuite([x.suite() for x in tests])
 res = unittest.TextTestRunner().run(SUITE)
